package token

import (
	"birdcall/internal/library/birdeye"
	"net/http"
	"net/url"
	"os"
	"strconv"

	"github.com/gogf/gf/util/gconv"
)

type Token struct{}

// GetListV1
//
//	@param chain_name
//	@param sort_by
//	@param sort_type
//	@param offset
//	@param limit
//	@param min_liquidity
//	@return *token.ListRes
//	@return error
func (t *Token) GetListV1(chain_name string, sort_by string, sort_type string, offset uint64, limit uint64, min_liquidity uint64) (*ListRes, error) {
	//构建基本请求连接
	baseURL := os.Getenv(birdeye.TOKEN_URL)
	params := url.Values{}
	params.Add(birdeye.SORT_BY, sort_by)
	params.Add(birdeye.SORT_TYPE, sort_type)
	params.Add(birdeye.OFFSET, strconv.FormatUint(offset, birdeye.TEN))
	params.Add(birdeye.LIMIT, strconv.FormatUint(limit, birdeye.TEN))
	params.Add(birdeye.MIN_LIQUIDITY, strconv.FormatUint(min_liquidity, birdeye.TEN))

	fullURL := baseURL + birdeye.TOKEN_LIST + birdeye.QUESTION_MARK + params.Encode()
	apiReq, err := http.NewRequest(birdeye.GET, fullURL, nil)
	if err != nil {
		return nil, err
	}
	//构建请求头
	apiReq = birdeye.MakeHeader(apiReq, chain_name)

	body, err := birdeye.SendRequest(apiReq)
	if err != nil {
		return nil, err
	}

	//处理返回数据
	var res *ListRes
	err = gconv.Struct(body, &res)
	if err != nil {
		return nil, err
	}
	return res, nil
}

func (t *Token) GetListV2(chain_name string) (*ListRes, error) {
	//构建基本请求连接
	baseURL := os.Getenv(birdeye.TOKEN_LIST_V2_URL)

	apiReq, err := http.NewRequest(birdeye.POST, baseURL, nil)
	if err != nil {
		return nil, err
	}
	//构建请求头
	apiReq = birdeye.MakeHeader(apiReq, chain_name)

	body, err := birdeye.SendRequest(apiReq)
	if err != nil {
		return nil, err
	}
	//处理返回数据
	var res *ListRes
	err = gconv.Struct(body, &res)
	if err != nil {
		return nil, err
	}
	return res, nil
}
