package wallet

import (
	"birdcall/internal/library/birdeye"
	"net/http"
	"net/url"
	"os"
	"strconv"

	"github.com/gogf/gf/util/gconv"
)

type Wallet struct{}

func (w *Wallet) Support() (*SupportRes, error) {
	//构建基本请求连接
	baseURL := os.Getenv(birdeye.WALLET_URL)
	fullURL := baseURL + birdeye.LIST_SUPPORTED_CHAIN

	apiReq, err := http.NewRequest(birdeye.GET, fullURL, nil)
	if err != nil {
		return nil, err
	}
	//构建请求头
	apiReq = birdeye.MakeHeader(apiReq)

	body, err := birdeye.SendRequest(apiReq)
	if err != nil {
		return nil, err
	}

	//处理返回数据
	var res *SupportRes
	err = gconv.Struct(body, &res)
	if err != nil {
		return nil, err
	}
	return res, nil
}

//	 TransactionHistory
//		@param wallet
//		@param limit
//		@param before
//		@return *w1.TransactionHistoryRes
//		@return error
func (w *Wallet) TransactionHistory(wallet string, limit int64, before string) (*TransactionHistoryRes, error) {
	//构建基本请求连接
	baseURL := os.Getenv(birdeye.WALLET_URL)
	params := url.Values{}
	params.Add(birdeye.WALLET, wallet)
	params.Add(birdeye.LIMIT, strconv.FormatInt(limit, 10))
	params.Add(birdeye.BEFORE, before)

	fullURL := baseURL + birdeye.TX_LIST + birdeye.QUESTION_MARK + params.Encode()

	apiReq, err := http.NewRequest(birdeye.GET, fullURL, nil)
	if err != nil {
		return nil, err
	}
	//构建请求头
	apiReq = birdeye.MakeHeader(apiReq)

	body, err := birdeye.SendRequest(apiReq)
	if err != nil {
		return nil, err
	}

	//处理返回数据
	var res *TransactionHistoryRes
	err = gconv.Struct(body, &res)
	if err != nil {
		return nil, err
	}
	return res, nil
}
